@@ -188,4 +188,33 @@ def get_seconds_from_epoch(datetime_obj):
     """
     from_epoch = datetime_obj - datetime(1970, 1, 1, tzinfo=pytz.UTC)
     from_epoch_seconds = from_epoch.total_seconds()
-    return from_epoch_seconds
\ No newline at end of file
+    return from_epoch_seconds
+
+def make_standard_time_fields():
+    """
+    Return
+        (dict): Times in iso (str) and from-epoch (int) formats
+    """
+    datetime_created = datetime.now(pytz.UTC)
+
+    time_created_epoch = get_seconds_from_epoch(datetime_created)
+    time_created_iso = datetime_created.isoformat()
+
+    time_fields = {
+                   'timeCreatedEpoch': time_created_epoch,
+                   'timeCreatedIso': time_created_iso,
+    }
+    return time_fields
+
+def get_datetime_iso8601(date_string):
+    """ Convert ISO 8601 date strings to datetime objects.
+
+    Google datetime format: https://tools.ietf.org/html/rfc3339
+    ISO 8601 standard format: https://en.wikipedia.org/wiki/ISO_8601
+
+    Args:
+        date_string (str): Date in ISO 8601 format
+    Returns
+        (datetime.datetime): Datetime objects
+    """
+    return iso8601.parse_date(date_string)
\ No newline at end of file
